<?php

namespace Drupal\commerceg_product\Group\RelationHandler;

// Drupal modules.
use Drupal\group\Plugin\Group\Relation\GroupRelationTypeManagerInterface;
use Drupal\group\Plugin\Group\RelationHandler\UiTextProviderInterface;
use Drupal\group\Plugin\Group\RelationHandler\UiTextProviderTrait;
// Drupal core.
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\TranslationInterface;

/**
 * Provides UI texts for product relations.
 */
class UiTextProvider implements UiTextProviderInterface {

  use UiTextProviderTrait;

  /**
   * Constructs a new UiTextProvider.
   *
   * @param \Drupal\group\Plugin\Group\RelationHandler\UiTextProviderInterface $parent
   *   The parent UI text provider.
   * @param \Drupal\Core\Session\AccountProxyInterface $account
   *   The current user account.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\group\Plugin\Group\Relation\GroupRelationTypeManagerInterface $group_relation_type_manager
   *   The group relation type plugin manager.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(
    UiTextProviderInterface $parent,
    AccountProxyInterface $account,
    EntityTypeManagerInterface $entity_type_manager,
    GroupRelationTypeManagerInterface $group_relation_type_manager,
    TranslationInterface $string_translation
  ) {
    $this->parent = $parent;

    // Injections required by traits.
    $this->currentUser = $account;
    $this->entityTypeManager = $entity_type_manager;
    $this->groupRelationTypeManager = $group_relation_type_manager;
    $this->stringTranslation = $string_translation;
  }

  /**
   * {@inheritdoc}
   */
  public function getAddPageDescription($create_mode) {
    $t_args = ['@entity_type' => $this->entityType->getSingularLabel()];

    $bundle = $this->groupRelationType->getEntityBundle();
    if (!$bundle) {
      return $create_mode
        ? $this->t('Create a new @entity_type in the group.', $t_args)
        : $this->t('Add an existing @entity_type to the group.', $t_args);
    }

    $t_args['%bundle'] = $this->entityTypeManager
      ->getStorage($this->entityType->getBundleEntityType())
      ->load($bundle)
      ->label();
    return $create_mode
      ? $this->t('Create a new @entity_type of type %bundle in the group.', $t_args)
      : $this->t('Add an existing @entity_type of type %bundle to the group.', $t_args);

  }

}
