<?php

namespace Drupal\commerceg_product\Plugin\Group\Relation;

// Drupal modules.
use Drupal\group\Plugin\Group\Relation\GroupRelationBase;
// Drupal core.
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
// Third-part libraries.
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a relation type for commerce products.
 *
 * @GroupRelationType(
 *   id = "commerceg_product",
 *   label = @Translation("Group product"),
 *   description = @Translation("Adds products to groups."),
 *   entity_type_id = "commerce_product",
 *   entity_access = TRUE,
 *   reference_label = @Translation("Title"),
 *   reference_description = @Translation("The title of the product to add to the group"),
 *   deriver = "Drupal\commerceg_product\Plugin\Group\Relation\ProductDeriver"
 * )
 *
 * @I Consider providing a plugin that permits all product bundles
 *    type     : feature
 *    priority : normal
 *    labels   : relation-type, product
 */
class Product extends GroupRelationBase implements
  ContainerFactoryPluginInterface {

  /**
   * Constructs a new Product object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    TranslationInterface $string_translation
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    // Injections required by traits.
    $this->stringTranslation = $string_translation;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('string_translation')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $config = parent::defaultConfiguration();
    $config['entity_cardinality'] = 1;

    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    FormStateInterface $form_state
  ) {
    $form = parent::buildConfigurationForm($form, $form_state);

    // Disable the entity cardinality field as the functionality of this module
    // relies on a cardinality of 1. We don't just hide it, though, to keep a UI
    // that's consistent with other group relations.
    $form['entity_cardinality']['#disabled'] = TRUE;
    $form['entity_cardinality']['#description'] .= '<br /><em>' . $this->t(
      "This field has been disabled by the plugin to guarantee the functionality
       that's expected of it."
    ) . '</em>';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    $dependencies = parent::calculateDependencies();
    $dependencies['config'][] = 'commerce_product.commerce_product_type.' . $this->getRelationType()->getEntityBundle();

    return $dependencies;
  }

}
