<?php

namespace Drupal\commerceg_product\Plugin\Group\Relation;

// Drupal modules.
use Drupal\group\Plugin\Group\Relation\GroupRelationTypeInterface;
// Drupal core.
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Config\Entity\ConfigEntityStorageInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;
// Third-party libraries.
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides per product bundle definitions of the group relation type plugin.
 */
class ProductDeriver extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * The product type storage.
   *
   * @var \Drupal\Core\Config\Entity\ConfigEntityStorageInterface
   */
  protected $productTypeStorage;

  /**
   * Constructs a new ProductDeriver object.
   *
   * @param \Drupal\Core\Config\Entity\ConfigEntityStorageInterface $product_type_storage
   *   The product type storage.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(
    ConfigEntityStorageInterface $product_type_storage,
    TranslationInterface $string_translation
  ) {
    $this->productTypeStorage = $product_type_storage;

    // Injections required by traits.
    $this->stringTranslation = $string_translation;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    $base_plugin_id
  ) {
    $product_type_storage = $container
      ->get('entity_type.manager')
      ->getStorage('commerce_product_type');

    return new static(
      $product_type_storage,
      $container->get('string_translation')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    assert($base_plugin_definition instanceof GroupRelationTypeInterface);
    $this->derivatives = [];

    foreach ($this->productTypeStorage->loadMultiple() as $name => $type) {
      $label = $type->label();

      $this->derivatives[$name] = clone $base_plugin_definition;
      $this->derivatives[$name]->set('entity_bundle', $name);
      $this->derivatives[$name]->set(
        'label',
        $this->t('Group product (@type)', ['@type' => $label])
      );
      $this->derivatives[$name]->set(
        'description',
        $this->t('Adds %type products to groups.', ['%type' => $label])
      );
    }

    return $this->derivatives;
  }

}
