<?php

namespace Drupal\commerceg\Configure;

/**
 * Interface for a configurator that provides default group roles.
 *
 * Modules of the Commerce Group ecosystem may provide default roles that should
 * be configured upon module installation. For example, the Commerce B2B module
 * provides a Manager and a Purchaser role, and the Commerce Product Group
 * module provides a Customer and a Group Customer role. The
 * `RoleConfiguratorInterface` together with the `RoleConfiguratorTrait` make it
 * easy to configure the required roles upon module installation.
 */
interface RoleConfiguratorInterface {

  /**
   * Configures the default group roles.
   *
   * It includes:
   *   - Resets the permissions for the default group roles to the default
   *     values. Permissions that are not related to functionality provided by
   *     module (as defined by the `getDefaultRolePermissions` method) will be
   *     left unchanged.
   *   - When a plugin ID is provided, only permissions defined by the plugin's
   *     permissions provider will be configured.
   *
   * @param string|null $plugin_id
   *   The plugin ID to filter the permissions for; if NULL, all permissions for
   *   the default roles will be configured.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   *   When a plugin ID is given but the plugin doesn't exist.
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   *   When the permission provider for the given plugin couldn't be loaded.
   */
  public function configureDefaultRoles(string $plugin_id = NULL);

}
