<?php

namespace Drupal\commerceg\Group;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Default implementation for the relationship loader service.
 */
class RelationshipLoader implements RelationshipLoaderInterface {

  /**
   * The Commerce Group relationship type loader.
   *
   * @var \Drupal\commerceg\Group\RelationshipTypeLoaderInterface
   */
  protected $relationshipTypeLoader;

  /**
   * The group relationship storage.
   *
   * @var \Drupal\group\Entity\Storage\GroupRelationshipStorageInterface
   */
  protected $relationshipStorage;

  /**
   * Constructs a new RelationshipLoader object.
   *
   * @param \Drupal\commerceg\Group\RelationshipTypeLoaderInterface $relationship_type_loader
   *   The Commerce Group relationship type loader.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(
    RelationshipTypeLoaderInterface $relationship_type_loader,
    EntityTypeManagerInterface $entity_type_manager
  ) {
    // Keep in mind that we should use Lazy Services if we add more methods that
    // do not use the Relationship Type Loader.
    // https://symfony.com/doc/current/service_container/lazy_services.html
    $this->relationshipTypeLoader = $relationship_type_loader;

    $this->relationshipStorage = $entity_type_manager->getStorage('group_relationship');
  }

  /**
   * {@inheritdoc}
   */
  public function loadForEntityByPluginIdAndGroupTypeId(
    EntityInterface $entity,
    string $plugin_id,
    string $group_type_id
  ) {
    $relationship_type = $this->relationshipTypeLoader->loadByPluginIdAndGroupTypeId(
      $plugin_id,
      $group_type_id
    );

    return $this->relationshipStorage->loadByProperties([
      'type' => $relationship_type->id(),
      'entity_id' => $entity->id(),
    ]);
  }

}
